summaryrefslogtreecommitdiffstats
path: root/lib/domain
diff options
context:
space:
mode:
authorMatthias Beyer <mail@beyermatthias.de>2019-05-29 18:06:12 +0200
committerMatthias Beyer <mail@beyermatthias.de>2019-05-31 12:48:00 +0200
commitc33c29e8e25812c77010dd140c49b3d48aa675af (patch)
treeec62df18290967106f07ba4ca03afdb1a7fb171a /lib/domain
parent098d25db896dd4ba627f36d172c300dc65033985 (diff)
Fix import for new libimagentryurl lib
Signed-off-by: Matthias Beyer <mail@beyermatthias.de>
Diffstat (limited to 'lib/domain')
-rw-r--r--lib/domain/libimagbookmark/src/collection.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/domain/libimagbookmark/src/collection.rs b/lib/domain/libimagbookmark/src/collection.rs
index 19f10f64..65890483 100644
--- a/lib/domain/libimagbookmark/src/collection.rs
+++ b/lib/domain/libimagbookmark/src/collection.rs
@@ -20,7 +20,7 @@
//! BookmarkCollection module
//!
//! A BookmarkCollection is nothing more than a simple store entry. One can simply call functions
//! from the libimagentrylink::external::ExternalLinker trait on this to generate external links.
//!
//! The BookmarkCollection type offers helper functions to get all links or such things.
@@ -34,7 +34,7 @@ use libimagstore::store::Store;
use libimagstore::store::Entry;
use libimagstore::store::FileLockEntry;
use libimagstore::storeid::StoreId;
-use libimagentrylink::external::ExternalLinker;
+use libimagentryurl::linker::UrlLinker;
use libimagentrylink::external::iter::UrlIter;
use libimagentrylink::internal::InternalLinker;
use libimagentrylink::internal::Link as StoreLink;
@@ -20,7 +20,7 @@
//!
//! A BookmarkCollection is nothing more than a simple store entry. One can simply call functions
-//! from the libimagentrylink::external::ExternalLinker trait on this to generate external links.
+//! from the libimagentryurl::linker::UrlLinker trait on this to generate external links.
//!
//! The BookmarkCollection type offers helper functions to get all links or such things.